<?php

defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

class FrontendModelBrowse extends JModel
{
  var $parameters;
  var $conditions = array();
  var $limitstart;
  var $images_per_page;
  var $settings;

  function __construct()
  {
    $this->settings = new HNConfig();
    $this->limitstart = JRequest::getVar('limitstart', 0, 'GET', 'integer');

    parent::__construct();
  }

  function setParameters($parameters)
  {
    $this->parameters = $parameters;

    if ($this->parameters['type'] == 'top')
    {
      if ($this->settings->top_images_per_page == 0)
      {
        $this->images_per_page = $this->settings->max_top_show;
      }
      else
      {
        if ($this->settings->max_top_show == 0)
        {
          $this->images_per_page = $this->settings->top_images_per_page;
        }
        else
        {
          $this->images_per_page = min($this->settings->max_top_show, $this->settings->top_images_per_page);
        }
      }
    }
    else
    {
      $this->images_per_page = $this->settings->top_images_per_page;
    }
  }

  function getParameters()
  {
    return $this->parameters;
  }

  function _buildQuery()
  {
    $this->setConditions();
    $orderby = $this->_buildOrderByCondition();

    switch ($this->getPhotoSource())
    {
      case 0:
        $query = $this->getQueryForHotornot();
      break;

      case 1:
        $query1 = $this->getQueryForHotornot();
        $query2 = $this->getQueryForLovefactory();

        $query = '(' . $query1 . ') UNION (' . $query2 . ') ' . $orderby;
      break;

      case 2:
        $query = $this->getQueryForLovefactory();
      break;
    }

    #var_dump(str_replace('#__', 'jos_', $query));

    return $query;
  }

  function getQueryForHotornot()
  {
    $orderby = $this->_buildOrderByCondition();

    $query = ' SELECT DISTINCT i.id, i.hits, i.rank, i.folder, i.extension, "hotornot" as source, i.user_id AS user_id, i.date_added AS date_added'
           . ' FROM #__hotornot_image i'
           . ' LEFT JOIN #__users u ON i.user_id = u.id'
           . ' LEFT JOIN #__hotornot_tag t ON i.id = t.image_id'
           . ' WHERE i.approved = 1'
           . $this->conditions
           . $orderby;

    return $query;
  }

  function getQueryForLovefactory()
  {
    $orderby = $this->_buildOrderByCondition();

    $query = ' SELECT DISTINCT p.id, i.hits, i.rank, "" AS folder, p.filename AS extension, "lovefactory" as source, p.user_id AS user_id, p.date_added AS date_added'
           . ' FROM #__lovefactory_photos p'
           . ' LEFT JOIN #__hotornot_image_lovefactory i ON p.id = i.image_id'
           . ' LEFT JOIN #__users u ON p.user_id = u.id'
           . ' LEFT JOIN #__hotornot_tag t ON i.rank = t.image_id'
           . ' WHERE i.approved = 1'
           . ' AND p.status = 0'
           . (($this->parameters['type'] == 'categorypictures' && JRequest::getVar('id', 0, 'GET', 'integer') == 0) ? '' : $this->conditions)
           . $orderby;

    return $query;
  }

  function _buildOrderByCondition()
  {
    switch ($this->parameters['type'])
    {
      case 'categorypictures':
        $orderby = ' ORDER BY date_added DESC';
      break;

      default:
        $orderby = ' ORDER BY rank DESC';
      break;
    }

    return $orderby;
  }

  function setConditions()
  {
    switch ($this->parameters['type'])
    {
      case 'top':
        $conditions = '';

        if (($this->limitstart > $this->settings->max_top_show) &&
            ($this->settings->max_top_show))
        {
          $this->limitstart = 0;
        }

        $conditions = ' AND i.hits >= ' . $this->settings->min_top_votes;
      break;

      case 'mypictures':
        $user       =& JFactory::getUser();
        $conditions =  ' AND user_id = ' . $user->id;
      break;

      case 'userpictures':
        $id         =& JRequest::getVar('id', 0, 'GET', 'integer');
        $conditions =  ' AND user_id = ' . $id;
      break;

      case 'categorypictures':
        $id         =& JRequest::getVar('id', 0, 'GET', 'integer');
        $conditions =  ' AND i.category_id = ' . $id;
      break;

      case 'search':
        switch ($this->parameters['search_type'])
        {
          // User
          case 1:
            $conditions = ' AND ' . $this->getSearchConditionsUser();
          break;

          // Tags
          case 2:
            $conditions = ' AND ' . $this->getSearchConditionsTags();
          break;

          // Description
          case 3:
            $conditions = ' AND ' . $this->getSearchConditionsDescription();
          break;

          default:
            $conditions = ' AND ( ' . $this->getSearchConditionsUser()
                        . ' OR '    . $this->getSearchConditionsTags()
                        . ' OR '    . $this->getSearchConditionsDescription() . ' )';
          break;
        }
      break;
    }

    $this->conditions = $conditions;
  }

  function getImages()
  {
    $query = $this->_buildQuery();

    $per_page = $this->images_per_page;

    if ($this->parameters['type'] == 'top')
    {
      if ((($this->images_per_page + $this->limitstart) > $this->settings->max_top_show) &&
          ($this->settings->max_top_show))
      {
        $per_page = $this->settings->max_top_show - $this->limitstart;
      }
    }

    $data = $this->_getList($query, $this->limitstart, $per_page);

    return $data;
  }

  function getTotal()
  {
    $query = $this->_buildQuery();
    $total = $this->_getListCount($query);

    if (($this->parameters['type'] == 'top') &&
        ($this->settings->max_top_show))
    {
      $total = min($this->settings->max_top_show, $total);
    }

    return $total;
  }

  function getPagination()
  {
    jimport('joomla.html.pagination');

    $pagination = new JPagination($this->getTotal(), $this->limitstart, $this->images_per_page);
    return $pagination;
  }

  function getSearchConditionsUser()
  {
    return $this->createCondition($this->parameters['search_query'], 'u.username', 'OR');
  }

  function getSearchConditionsTags()
  {
    return $this->createCondition($this->parameters['search_query'], 't.name', 'OR');
  }

  function getSearchConditionsDescription()
  {
    return $this->createCondition($this->parameters['search_query'], 'i.description', 'OR');
  }

  function createCondition($search_query, $field_name, $operand)
  {
    $database =& JFactory::getDBO();

    $queries = explode(',', $search_query);
    $condition = '(';

    $first = true;
    foreach ($queries as $query)
    {
      if (!$first)
      {
        $condition .= ' ' . $operand . ' ';
      }

      $query = $database->getEscaped(trim($query));
      $condition .= $field_name . ' LIKE "%' . $query . '%"';
      $first = false;
    }
    $condition .= ')';
    return $condition;
  }

  function getPhotoSource()
  {
    $settings = new HNConfig();

    if (!$this->getLoveFactoryIntegration())
    {
      return 0;
    }

    return $settings->photos_source;
  }

  function getLoveFactoryIntegration()
  {
    $query = ' SELECT COUNT(id)'
           . ' FROM #__components'
           . ' WHERE link = "option=com_lovefactory"';
    $this->_db->setQuery($query);

    return (boolean)$this->_db->loadResult();
  }
}