<?php

defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

class FrontendModelUpload extends JModel
{
  function __construct()
  {
    parent::__construct();
  }

  function getOutput()
  {
    $output = array();
    $errors = Helper::validUpload();

    foreach ($_FILES as $field => $value)
    {
      if ((preg_match('/file_(?P<digit>\d+)/', $field, $matches)) &&
          (!empty($value['tmp_name'])))
      {
        $id = $matches['digit'];

        if (!array_key_exists($id, $errors))
        {
          $upload = $this->upload($id);
          if ($upload)
          {
            $output[$id] = $value['name'] . ' ' . JText::_('uploaded succesfully');
          }
          else
          {
            $output[$id] = $value['name'] . ' ' . JText::_('not uploaded:') . ' ' . $this->getError();
          }
        }
        else
        {
          $output[$id] = '';
          if (count($errors[$id]))
          {
            $output[$id] .= '<div style="color: #ff0000;">';
            $output[$id] .= '<b>' . JText::_('There were errors trying to upload') . ' ' . $value['name'] . '</b><br />';

            foreach ($errors[$id] as $error)
            {
              $output[$id] .= $error . '<br />';
            }

            $output[$id] .= '<div>';
          }
        }
      }
    }

    return $output;
  }

  function upload($upload_id)
  {
    $counter  = new HNCounter();
    $settings = new HNConfig();

    $file = JRequest::getVar('file_'.$upload_id, '', 'files', 'array' );

    // Check if it is image
    if (strpos($file['type'], 'image') === false)
    {
      $this->setError(JText::_('File is not an image.'));
      return false;
    }

    // Do not allow BMP files
    if (strpos($file['type'], 'bmp') !== false)
    {
      $this->setError(JText::_('BMP files are not allowed!'));
      return false;
    }

    // Check for minimum size requiremets
    $file_info = getimagesize($file['tmp_name']);
    if ($file_info[0] < $settings->image_min_width || $file_info[1] < $settings->image_min_height)
    {
      $this->setError(JText::_('Image doesn\'t meet the minimum size requirements.'));
      return false;
    }

    $path = Helper::decodePath($settings->upload_folder);

    if (is_dir($path.DS.$counter->current_folder))
    {
      if ($counter->current_count < 1000)
      {
        $counter->current_count += 2;
      }
      else
      {
        $counter->current_folder++;
        mkdir($path.DS.$counter->current_folder);
        $counter->current_count = 2;
      }
    }
    else
    {
      mkdir($path.DS.$counter->current_folder);
      $counter->current_count = 2;
    }

    Helper::saveCounter($counter);

    jimport('joomla.filesystem.file');
    $extension = strtolower(JFile::getExt($file['name']));

    $database    =& JFactory::getDBO();
    $user        =& JFactory::getUser();
    $category    =& JRequest::getVar('category_' . $upload_id,    0,  'POST', 'integer');
    $description =& JRequest::getVar('description_' . $upload_id, '', 'POST', 'string');
    $datenow     =& JFactory::getDate();
    $image       =& $this->getTable('image', 'Table');

    $image->user_id     = $user->id;
    $image->folder      = $counter->current_folder;
    $image->extension   = $extension;
    $image->description = $description;
    $image->date_added  = $datenow->toMySQL();
    $image->category_id = $category;

    if ($settings->enable_image_approval_system == 0)
    {
      $image->approved = 1;
    }

    $image->store();

    $id = $image->id;

    require_once(JPATH_COMPONENT.DS.'resizeIMG.php');

    $filepath = JPath::clean($path.DS.$counter->current_folder.DS.$id.'.'.$extension);
    $resize = new RESIZEIMAGE($file['tmp_name']);
    $resize->resize_scale($settings->image_max_width, $settings->image_max_width, $filepath);
    $resize->close();

    $this->addWatermark($filepath);

    $filepath = JPath::clean($path.DS.$counter->current_folder.DS.$id.'_thumb.'.$extension);
    $resize = new RESIZEIMAGE($file['tmp_name']);
    $resize->resize_scale($settings->thumbnail_max_width, $settings->thumbnail_max_width, $filepath);
    $resize->close();

    if ($settings->allow_tags)
    {
      $tags = JRequest::getVar('tags_'.$upload_id, '', 'POST', 'string');
      $tags = explode(',', $tags);

      $tag_query = '';

      foreach ($tags as $tag)
      {
        $tag = $database->getEscaped(trim($tag));
        $tag_query .= (!empty($tag)) ? '("", ' . $id . ', "' . $tag . '"),' : '';
      }

      if (!empty($tag_query))
      {
        $tag_query = substr($tag_query, 0, strlen($tag_query) - 1);

        $query = ' INSERT INTO #__hotornot_tag'
               . ' VALUES'
               . $tag_query;
        $database->setQuery($query);
        $database->query();
      }
    }

    if ($settings->enable_notification_new_image_uploaded)
    {
      // Send notification
      $this->sendNotification();
    }

    return true;
  }

  function getCategories()
  {
    $query = ' SELECT c.id, c.title, c.icon'
           . ' FROM #__hotornot_categories c'
           . ' WHERE c.published = 1'
           . ' ORDER BY c.ordering ASC';
    $this->_db->setQuery($query);

    return $this->_db->loadObjectList();
  }

  function sendNotification()
  {
    $settings = new HNConfig();

    if (count($settings->notification_new_image_uploaded_receivers))
    {
      // Get the admins emails
      $query = ' SELECT u.id, u.username, u.email'
             . ' FROM #__users u'
             . ' WHERE u.id IN (' . implode(',', $settings->notification_new_image_uploaded_receivers) . ')';
      $this->_db->setQuery($query);
      $admins = $this->_db->loadObjectList();

      $subject = base64_decode($settings->notification_new_image_uploaded_subject);
      $message = base64_decode($settings->notification_new_image_uploaded_message);

      foreach ($admins as $admin)
      {
        if ($settings->enable_html_emails)
        {
          $subject = nl2br($subject);
          $message = nl2br($message);
        }

        // Send the mail
        $mail =& JFactory::getMailer();
        $mail->addRecipient($admin->email);

        $mail->setSubject(JText::_($subject));
        $mail->setBody(JText::_($message));

        $mail->IsHTML($settings->enable_html_emails);

        $mail->send();
      }

    }
  }

  function addWatermark($filepath)
  {
    $settings = new HNConfig();

    if ($settings->enable_watermark &&
        !empty($settings->watermark_path) &&
        file_exists(JPATH_COMPONENT_SITE.DS.'upload'.DS.'watermark'.DS.$settings->watermark_path))
    {
      $watermark_path = JPATH_COMPONENT_SITE.DS.'upload'.DS.'watermark'.DS.$settings->watermark_path;
      $watermark      = getimagesize($watermark_path);
      $file           = getimagesize($filepath);

      switch ($watermark['mime'])
      {
        case 'image/png';
          $watermark_image = @imagecreatefrompng($watermark_path);
        break;

        case 'image/gif';
          $watermark_image = @imagecreatefromgif($watermark_path);
        break;

        case 'image/jpg':
        case 'image/jpeg':
          $watermark_image = @imagecreatefromjpeg($watermark_path);
        break;
      }

      switch ($file['mime'])
      {
        case 'image/jpg':
        case 'image/jpeg':
          $file_image = @imagecreatefromjpeg($filepath);
        break;

        case 'image/png';
          $file_image = @imagecreatefrompng($file_image);
        break;

        case 'image/gif';
          $file_image = @imagecreatefromgif($file_image);
        break;
      }

      $imagewidth      = imagesx($file_image);
      $imageheight     = imagesy($file_image);
      $watermarkwidth  = imagesx($watermark_image);
      $watermarkheight = imagesy($watermark_image);

      switch ($settings->watermark_position_y)
      {
        // Top
        case 1:
          if ($watermarkheight + $settings->watermark_margin <= $imageheight)
          {
            $start_y = $settings->watermark_margin;
          }
          else
          {
            $start_y = 0;
          }
        break;

        // Middle
        case 2:
          $start_y = (($imageheight - $watermarkheight) / 2);
        break;

        // Bottom
        case 3:
          if ($watermarkheight + $settings->watermark_margin <= $imageheight)
          {
            $start_y = $imageheight - $watermarkheight - $settings->watermark_margin;
          }
          else
          {
            $start_y = $imageheight - $watermarkheight;
          }
        break;
      }

      switch ($settings->watermark_position_x)
      {
        // Left
        case 1:
          if ($watermarkwidth + $settings->watermark_margin <= $imagewidth)
          {
            $start_x = $settings->watermark_margin;
          }
          else
          {
            $start_x = 0;
          }
        break;

        // Center
        case 2:
          $start_x = (($imagewidth - $watermarkwidth) / 2);
        break;

        // Right
        case 3:
          if ($watermarkwidth + $settings->watermark_margin <= $imagewidth)
          {
            $start_x = $imagewidth - $watermarkwidth - $settings->watermark_margin;
          }
          else
          {
            $start_x = $imagewidth - $watermarkwidth;
          }
        break;
      }

      imagecopy($file_image, $watermark_image, $start_x, $start_y, 0, 0, $watermarkwidth, $watermarkheight);
      imagejpeg($file_image, $filepath);

      imagedestroy($file_image);
      imagedestroy($watermark_image);
    }
  }
}